@@ -1,8 +1,9 @@
+import os
 import unittest
 
 from rdflib import Graph
 
-from tests import RDFLIB_PARSING_ISSUE_FIXED
+from tests import datadir
 
 """ Test for an error in the RDFLIB parser.  To fix the bug in rdflib 4.2.2:
 > rdflib.plugins.parsers.notation3.py
@@ -14,9 +15,8 @@ from tests import RDFLIB_PARSING_ISSUE_FIXED
 
 
 class RDFLIBTestCase(unittest.TestCase):
-    @unittest.skipIf(not RDFLIB_PARSING_ISSUE_FIXED, "Waiting for RDFLIB quote fix")
     def test_parser(self):
-        rdff = "/users/hsolbri1/git/shexSpec/shexTest/validation/Is1_Ip1_LSTRING_LITERAL1_with_all_punctuation.ttl"
+        rdff = os.path.join(datadir, 'validation', 'Is1_Ip1_LSTRING_LITERAL1_with_all_punctuation.ttl')
         with open(rdff, 'rb') as f:
             rdf = f.read().decode()
         Graph().parse(data=rdf, format="turtle")
